summaryrefslogtreecommitdiffstats
path: root/src/include/gpxe/http.h
diff options
context:
space:
mode:
authorMichael Brown2007-01-31 03:09:13 +0100
committerMichael Brown2007-01-31 03:09:13 +0100
commit6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de (patch)
tree9ba9ac5ba0a755bdb6f10a563b22dac61ef4045d /src/include/gpxe/http.h
parentFirst sketch of stream API (diff)
downloadipxe-6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de.tar.gz
ipxe-6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de.tar.xz
ipxe-6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de.zip
Changed to use the generic stream API.
Diffstat (limited to 'src/include/gpxe/http.h')
-rw-r--r--src/include/gpxe/http.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/gpxe/http.h b/src/include/gpxe/http.h
index 3cfc888a4..911a74851 100644
--- a/src/include/gpxe/http.h
+++ b/src/include/gpxe/http.h
@@ -8,7 +8,7 @@
*/
#include <stdint.h>
-#include <gpxe/tcp.h>
+#include <gpxe/stream.h>
#include <gpxe/async.h>
#include <gpxe/linebuf.h>
#include <gpxe/uri.h>
@@ -43,8 +43,8 @@ struct http_request {
/** Server address */
struct sockaddr server;
- /** TCP application for this request */
- struct tcp_application tcp;
+ /** Stream application for this request */
+ struct stream_application stream;
/** Number of bytes already sent */
size_t tx_offset;
/** RX state */